==> Zombie-Villager-Variants-1.0.0-sources.jar: fun/wich/VillagerHuskEntity.java <==
package fun.wich;

import net.minecraft.class_10179;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1641;
import net.minecraft.class_1646;
import net.minecraft.class_1916;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3730;
import net.minecraft.class_4136;
import net.minecraft.class_5425;
import net.minecraft.class_5819;
import net.minecraft.class_6088;
import net.minecraft.class_9334;

public class VillagerHuskEntity extends class_1641 {
	public VillagerHuskEntity(class_1299<? extends class_1641> entityType, class_1937 world) { super(entityType, world); }

	public static boolean canSpawn(class_1299<VillagerHuskEntity> type, class_5425 world, class_3730 spawnReason, class_2338 pos, class_5819 random) {
		return method_20680(type, world, spawnReason, pos, random) && (class_3730.method_54986(spawnReason) || world.method_8311(pos));
	}

	@Override
	public void method_5711(byte status) {
		if (status == 16) {
			if (!this.method_5701()) {
				this.method_73183().method_8486(this.method_23317(), this.method_23320(), this.method_23321(), ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_CURE, this.method_5634(), 1.0F + this.field_5974.method_43057(), this.field_5974.method_43057() * 0.7F + 0.3F, false);
			}
		}
		else super.method_5711(status);
	}
	@Override
	public boolean method_7216() { return false; }
	@Override
	public class_3414 method_5994() { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_AMBIENT; }
	@Override
	public class_3414 method_6011(class_1282 source) { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_HURT; }
	@Override
	public class_3414 method_6002() { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_DEATH; }
	@Override
	public class_3414 method_7207() { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_STEP; }

	@Override
	public boolean method_6121(class_3218 world, class_1297 target) {
		boolean bl = super.method_6121(world, target);
		if (bl && this.method_6047().method_7960() && target instanceof class_1309) {
			float f = this.method_73183().method_8404(this.method_24515()).method_5457();
			((class_1309)target).method_37222(new class_1293(class_1294.field_5903, 140 * (int)f), this);
		}

		return bl;
	}

	@Override
	protected boolean method_7209() { return true; }

	@Override
	protected void method_7218() {
		this.ConvertToZombieVillagerEntity();
		if (!this.method_5701()) {
			this.method_73183().method_8444(null, class_6088.field_31129, this.method_24515(), 0);
		}
	}

	protected void ConvertToZombieVillagerEntity() {
		this.method_29243((class_1299<? extends class_1641>) class_1299.field_6054, class_10179.method_63607(this, true, true), zombieVillager -> {
			class_1937 world = method_73183();
			if (world instanceof class_3218 serverWorld) zombieVillager.method_5943(serverWorld, method_73183().method_8404(zombieVillager.method_24515()), class_3730.field_16468, new class_1644(false, true));
			zombieVillager.method_7195(method_7231());
			zombieVillager.method_66653(class_9334.field_56145, method_58694(class_9334.field_56145));
			class_4136 gossip = ((OfferGossipExposing)this).GetGossip();
			if (gossip != null) zombieVillager.method_21649(gossip.method_67658());
			class_1916 offers = ((OfferGossipExposing)this).GetOfferData();
			if (offers != null) zombieVillager.method_16916(offers.method_53882());
			zombieVillager.method_19622(method_35194());
			zombieVillager.method_7195(method_7231());
			if (!this.method_5701()) {
				world.method_8444(null, class_6088.field_31114, this.method_24515(), 0);
			}
		});
	}

	@Override
	public boolean method_63654(class_3218 world, class_1646 villager) {
		class_1641 zombieVillagerEntity = villager.method_29243(ZombieVillagerVariants.VILLAGER_HUSK, class_10179.method_63607(villager, true, true), zombieVillager -> {
			zombieVillager.method_5943(world, world.method_8404(zombieVillager.method_24515()), class_3730.field_16468, new class_1644(false, true));
			zombieVillager.method_7195(villager.method_7231());
			zombieVillager.method_21649(villager.method_21651().method_67658());
			zombieVillager.method_16916(villager.method_8264().method_53882());
			zombieVillager.method_19622(villager.method_19269());
			if (!this.method_5701()) {
				world.method_8444(null, class_6088.field_31114, this.method_24515(), 0);
			}
		});
		return zombieVillagerEntity != null;
	}
}

==> Zombie-Villager-Variants-1.1.2-sources.jar: fun/wich/VillagerHuskEntity.java <==
package fun.wich;

import net.minecraft.class_10179;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1641;
import net.minecraft.class_1646;
import net.minecraft.class_1916;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3730;
import net.minecraft.class_4136;
import net.minecraft.class_5425;
import net.minecraft.class_5819;
import net.minecraft.class_6088;
import net.minecraft.class_9334;

public class VillagerHuskEntity extends class_1641 {
	public VillagerHuskEntity(class_1299<? extends class_1641> entityType, class_1937 world) { super(entityType, world); }
	public static boolean canSpawn(class_1299<VillagerHuskEntity> type, class_5425 world, class_3730 spawnReason, class_2338 pos, class_5819 random) {
		return method_20680(type, world, spawnReason, pos, random) && (class_3730.method_54986(spawnReason) || world.method_8311(pos));
	}
	@Override
	public void method_5711(byte status) {
		if (status == 16) {
			if (!this.method_5701()) {
				this.method_73183().method_8486(this.method_23317(), this.method_23320(), this.method_23321(), ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_CURE, this.method_5634(), 1.0F + this.field_5974.method_43057(), this.field_5974.method_43057() * 0.7F + 0.3F, false);
			}
		}
		else super.method_5711(status);
	}
	@Override
	public boolean method_7216() { return false; }
	@Override
	public class_3414 method_5994() { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_AMBIENT; }
	@Override
	public class_3414 method_6011(class_1282 source) { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_HURT; }
	@Override
	public class_3414 method_6002() { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_DEATH; }
	@Override
	public class_3414 method_7207() { return ZombieVillagerVariants.ENTITY_VILLAGER_HUSK_STEP; }
	@Override
	public boolean method_6121(class_3218 world, class_1297 target) {
		boolean bl = super.method_6121(world, target);
		if (bl && this.method_6047().method_7960() && target instanceof class_1309) {
			float f = this.method_73183().method_8404(this.method_24515()).method_5457();
			((class_1309)target).method_37222(new class_1293(class_1294.field_5903, 140 * (int)f), this);
		}
		return bl;
	}
	@Override
	protected boolean method_7209() { return true; }
	@Override
	protected void method_7218() {
		this.ConvertToZombieVillagerEntity();
		if (!this.method_5701()) this.method_73183().method_8444(null, class_6088.field_31129, this.method_24515(), 0);
	}
	protected void ConvertToZombieVillagerEntity() {
		this.method_29243((class_1299<? extends class_1641>) class_1299.field_6054, class_10179.method_63607(this, true, true), zombieVillager -> {
			class_1937 world = method_73183();
			if (world instanceof class_3218 serverWorld) zombieVillager.method_5943(serverWorld, method_73183().method_8404(zombieVillager.method_24515()), class_3730.field_16468, new class_1644(false, true));
			zombieVillager.method_7195(method_7231());
			zombieVillager.method_66653(class_9334.field_56145, method_58694(class_9334.field_56145));
			class_4136 gossip = ((OfferGossipExposing)this).GetGossip();
			if (gossip != null) zombieVillager.method_21649(gossip.method_67658());
			class_1916 offers = ((OfferGossipExposing)this).GetOfferData();
			if (offers != null) zombieVillager.method_16916(offers.method_53882());
			zombieVillager.method_19622(method_35194());
			zombieVillager.method_7195(method_7231());
			if (!this.method_5701()) world.method_8444(null, class_6088.field_31114, this.method_24515(), 0);
		});
	}
	@Override
	public boolean method_63654(class_3218 world, class_1646 villager) {
		class_1641 zombieVillagerEntity = villager.method_29243(ZombieVillagerVariants.VILLAGER_HUSK, class_10179.method_63607(villager, true, true), zombieVillager -> {
			zombieVillager.method_5943(world, world.method_8404(zombieVillager.method_24515()), class_3730.field_16468, new class_1644(false, true));
			zombieVillager.method_7195(villager.method_7231());
			zombieVillager.method_21649(villager.method_21651().method_67658());
			zombieVillager.method_16916(villager.method_8264().method_53882());
			zombieVillager.method_19622(villager.method_19269());
			if (!this.method_5701()) world.method_8444(null, class_6088.field_31114, this.method_24515(), 0);
		});
		return zombieVillagerEntity != null;
	}
}
